@@ -9,7 +9,7 @@
  *  (at your option) any later version.
  *
  *  HomeBank is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty ofdefoperation_amountchanged
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
@@ -17,11 +17,14 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "homebank.h"
 
-#include "dsp_account.h"
 #include "def_operation.h"
+#include "dsp_account.h"
+#include "hb_transaction.h"
+#include "ui_account.h"
+#include "ui_category.h"
+#include "ui_payee.h"
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -69,6 +72,7 @@ struct defoperation_data
 	GtkWidget	*PO_grp;
 	GtkWidget	*PO_acc;
 	GtkWidget	*PO_accto;
+	GtkWidget	*ST_tags;
 
 	gulong		handler_id[MAX_HID];
 };
@@ -78,7 +82,7 @@ static void defoperation_update		(GtkWidget *widget, gpointer user_data);
 static void defoperation_setup(struct defoperation_data *data);
 static void defoperation_set(GtkWidget *widget, gpointer user_data);
 static void defoperation_update_child_transfert(Operation *src, Operation *dst);
-
+static void defoperation_update_transfert(GtkWidget *widget, gpointer user_data);
 
 extern gchar *CYA_TYPE[];
 
@@ -96,7 +100,7 @@ static void defoperation_set(GtkWidget *widget, gpointer user_data)
 {
 struct defoperation_data *data;
 Operation *entry;
-gchar *txt;
+gchar *tagstr, *txt;
 
 	DB( g_printf("(defoperation) set\n") );
 
@@ -106,6 +110,9 @@ gchar *txt;
 
 	DB( g_printf(" -> ope=%8x data=%x\n", (gint)data->ope, data) );
 
+	DB( g_print(" -> tags at: '%x'\n", entry->tags) );
+
+
 	//DB( g_printf(" set date to %d\n", entry->date) );
 	//g_object_set(GTK_DATE_ENTRY(data->PO_date), "date", (guint32)entry->ope_Date);
 	gtk_dateentry_set_date(GTK_DATE_ENTRY(data->PO_date), (guint)entry->date);
@@ -120,16 +127,26 @@ gchar *txt;
 
 	txt = (entry->info != NULL) ? entry->info : "";
 	gtk_entry_set_text(GTK_ENTRY(data->ST_info), txt);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_grp), entry->category);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_pay), entry->payee);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_acc), entry->account);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_accto), entry->dst_account);
-	
+	ui_cat_comboboxentry_set_active(GTK_COMBO_BOX_ENTRY(data->PO_grp), entry->category);
+	ui_pay_comboboxentry_set_active(GTK_COMBO_BOX_ENTRY(data->PO_pay), entry->payee);
+
+	tagstr = transaction_get_tagstring(entry);
+
+	DB( g_print(" -> tags: '%s'\n", txt) );
+
+	txt = (tagstr != NULL) ? tagstr : "";
+	gtk_entry_set_text(GTK_ENTRY(data->ST_tags), txt);
+	g_free(tagstr);
+
 	//as we trigger an event on this
 	//let's place it at the end to avoid misvalue on the trigger function
+	
+	ui_acc_comboboxentry_set_active(GTK_COMBO_BOX_ENTRY(data->PO_acc), entry->account);
+	ui_acc_comboboxentry_set_active(GTK_COMBO_BOX_ENTRY(data->PO_accto), entry->dst_account);
+	
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->NU_mode), entry->paymode);
 	
-	DB( g_print(" acc is: %d\n", gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc)) ) );
+	DB( g_print(" -> acc is: %d\n", gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc)) ) );
 }
 
 /*
@@ -213,10 +230,19 @@ gint active;
 		entry->info = g_strdup(txt);
 	}
 
-	entry->category   = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_grp));
-	entry->payee   = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_pay));
-	entry->account = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc));
-	entry->dst_account = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_accto));
+	entry->category    = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_grp));
+	entry->payee       = ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_pay));
+	entry->account     = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
+	entry->dst_account = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
+
+	/* tags */
+	txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
+	if (txt && *txt)
+	{
+		DB( g_print(" -> tags: '%s'\n", txt) );
+		
+		transaction_set_tags(entry, txt);
+	}
 
 	/* flags */
 	entry->flags &= (OF_AUTO|OF_ADDED);
@@ -362,7 +388,7 @@ gint page;
 
 				if( active != -1 )
 				{
-					acc = g_list_nth_data(GLOBALS->acc_list, active);
+					acc = da_acc_get( active );
 					cheque = ( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_cheque))==TRUE ? acc->cheque2 : acc->cheque1 );
 					cheque_str = g_strdup_printf("%d", cheque + 1);
 					gtk_entry_set_text(GTK_ENTRY(data->ST_info), cheque_str);
@@ -382,8 +408,67 @@ gint page;
 	DB( g_printf(" payment: %d, page: %d\n", payment, page) );
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(data->notebook), page);
+	
+	defoperation_update_transfert(widget, user_data);
 }
 
+static void defoperation_update_accto(GtkWidget *widget, gpointer user_data)
+{
+struct defoperation_data *data;
+guint kacc;
+
+	DB( g_printf("(defoperation) update accto\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	kacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
+
+	DB( g_printf(" acc is %d\n", kacc) );
+
+
+	ui_acc_comboboxentry_populate_except(GTK_COMBO_BOX_ENTRY(data->PO_accto), GLOBALS->h_acc, kacc);
+
+	defoperation_update_transfert(widget, user_data);
+}
+
+
+
+static void defoperation_update_transfert(GtkWidget *widget, gpointer user_data)
+{
+struct defoperation_data *data;
+gboolean sensitive;
+	guint kacc, kdst;
+
+	DB( g_printf("(defoperation) update transfert\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	sensitive = TRUE;
+
+	kacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
+
+	if(kacc == 0) sensitive = FALSE;
+
+	/* coherent saise */
+	if( gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode)) == PAYMODE_PERSTRANSFERT )
+	{
+
+		kdst = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
+	
+		//sensitive = kdst > 0 ? (kacc == kdst ? FALSE : TRUE) : FALSE;
+		if(kdst == 0) sensitive = FALSE;
+		if(kdst == kacc) sensitive = FALSE;
+		
+		DB( g_printf(" sensitive %d\n", sensitive) );
+		
+		
+	}	
+
+	gtk_widget_set_sensitive(GTK_DIALOG(data->window)->action_area, sensitive);
+
+}
+
+
 /*
 ** update the widgets status and contents from action/selection value
 */
@@ -473,10 +558,11 @@ gboolean active;
 	DB( g_print("(defoperation) update child transfert\n") );
 
 	/* update the child transfert */
-	dst->date      = src->date;
+	dst->date     = src->date;
 	dst->amount	  = -src->amount;
 	dst->payee	  = src->payee;
 	dst->category = src->category;
+	dst->flags    = src->flags;
 	if( dst->wording ) { g_free(dst->wording); dst->wording = NULL; }
 	if( src->wording ) dst->wording = g_strdup(src->wording);
 	if( dst->info ) { g_free(dst->info); dst->info = NULL; }
@@ -487,7 +573,7 @@ gboolean active;
 	if(active == TRUE) dst->flags |= OF_INCOME;
 
 	/* mark account as changed */
-	acc = g_list_nth_data(GLOBALS->acc_list, src->dst_account);
+	acc = da_acc_get( src->dst_account );
 	if( acc)
 		acc->flags |= AF_CHANGED;
 
@@ -512,7 +598,7 @@ struct defoperation_data *data;
 **
 */
 /*
-gboolean defoperation_cleanup(struct defoperation_data *data, gint result)
+static gboolean defoperation_cleanup(struct defoperation_data *data, gint result)
 {
 gboolean doupdate = FALSE;
 
@@ -541,10 +627,10 @@ static void defoperation_setup(struct defoperation_data *data)
 
     gtk_window_set_title (GTK_WINDOW (data->window), _(CYA_OPERATION[data->type]));
 
-	make_poppayee_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->pay_list);
-	make_popcategory_populate(GTK_COMBO_BOX(data->PO_grp), GLOBALS->cat_list);
-	make_popaccount_populate(GTK_COMBO_BOX(data->PO_acc), GLOBALS->acc_list);
-	make_popaccount_populate(GTK_COMBO_BOX(data->PO_accto), GLOBALS->acc_list);
+	ui_pay_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_pay), GLOBALS->h_pay);
+	ui_cat_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_grp), GLOBALS->h_cat);
+	ui_acc_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_acc), GLOBALS->h_acc);
+	ui_acc_comboboxentry_populate(GTK_COMBO_BOX_ENTRY(data->PO_accto), GLOBALS->h_acc);
 
 	if( data->type != OPERATION_EDIT_MODIFY )
 		make_poparchive_populate(GTK_COMBO_BOX(data->PO_arc), GLOBALS->arc_list);
@@ -582,11 +668,14 @@ gint row;
 	data->PO_date = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
+	gtk_widget_set_tooltip_text(widget, _("Date accepted here are:\nday,\nday/month or month/day,\nand complete date into your locale"));
+
 	row++;
 	label = gtk_label_new_with_mnemonic (_("_Description:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_string(label);
+	//widget = make_string(label);
+	widget = make_memo_entry(label);
 	data->ST_word = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -611,7 +700,7 @@ gint row;
 	label = gtk_label_new_with_mnemonic (_("A_ccount:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_popaccount(label);
+	widget = ui_acc_comboboxentry_new(label);
 	data->PO_acc = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -674,8 +763,8 @@ gint row;
 		hbox = gtk_hbox_new(FALSE, HB_BOX_SPACING);
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hbox, NULL);
 		label = make_label(_("_To account:"), 0, 0.5);
-		gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-		widget = make_popaccount(label);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		widget = ui_acc_comboboxentry_new(label);
 		data->PO_accto = widget;
 		gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
@@ -692,18 +781,30 @@ gint row;
 	label = gtk_label_new_with_mnemonic (_("_Payee:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_poppayee(label);
+	widget = ui_pay_comboboxentry_new(label);
 	data->PO_pay = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
 
+	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct saise\nis available for Payee"));
+
 	row++;
 	label = gtk_label_new_with_mnemonic (_("_Category:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_popcategory(label);
+	widget = ui_cat_comboboxentry_new(label);
 	data->PO_grp = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
 
+	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct saise\nis available for Category"));
+
+	row++;
+	label = gtk_label_new_with_mnemonic (_("_Tags:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_string(label);
+	data->ST_tags = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
+
 	return table;
 }
 
@@ -716,7 +817,7 @@ gboolean defoperation_delete(GtkWidget *widget, GdkEvent *event, gpointer user_d
 */
 
 // the window creation
-GtkWidget *create_defoperation_window (Operation *ope, gint type, gint accnum)
+GtkWidget *create_defoperation_window (GtkWindow *parent, Operation *ope, gint type, gint accnum)
 {
 struct defoperation_data *data;
 GtkWidget *window, *hbox, *mainbox, *table, *label, *widget;
@@ -728,7 +829,7 @@ GtkWidget *alignment;
 	//parentwindow = gtk_widget_get_ancestor(treeview, GTK_TYPE_WINDOW);
 
       window = gtk_dialog_new_with_buttons (NULL,
-					    /*GTK_WINDOW (parentwindow), */ NULL,
+					    GTK_WINDOW (parent),
 					    0,
 					    NULL,
 					    NULL);
@@ -828,6 +929,11 @@ GtkWidget *alignment;
 
 	g_signal_connect (data->CM_valid, "toggled", G_CALLBACK (defoperation_update), NULL);
 
+	g_signal_connect (data->PO_acc, "changed", G_CALLBACK (defoperation_update_accto), NULL);
+
+
+	g_signal_connect (data->PO_accto, "changed", G_CALLBACK (defoperation_update_transfert), NULL);
+
 	//setup, init and show window
 
 	defoperation_setup(data);
