@@ -22,29 +22,30 @@
 
 #include <config.h>
 
+#include <ctype.h> 		/* isprint */
+#include <errno.h>
+#include <math.h>
+#include <libintl.h>
+#include <locale.h>
+#include <stdlib.h>		/* atoi, atof, atol */
+#include <string.h>		/* memset, memcpy, strcmp, strcpy */
+#include <time.h>
+
 #include <glib.h>
-#include <glib/gprintf.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 
-#include <errno.h>
-#include <math.h>
-#include <stdlib.h>		/* atoi, atof, atol */
-#include <string.h>		/* memset, memcpy, strcmp, strcpy */
-
-#include <locale.h>
-#include <time.h>
-
 #include "enums.h"
 #include "preferences.h"
-#include "data_access.h"
-#include "widgets.h"
-#include "misc.h"
+#include "da_other.h"
+#include "da_account.h"
+#include "da_category.h"
+#include "da_payee.h"
+#include "da_transaction.h"
+#include "da_tag.h"
 #include "gtkdateentry.h"
-#include "gtkchart.h"
-
-#include <libintl.h>
-#include <locale.h>
+#include "misc.h"
+#include "widgets.h"
 
 #define _(str) gettext (str)
 #define gettext_noop(str) (str)
@@ -55,20 +56,38 @@
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-#define	PROGNAME		"HomeBank"
-//#define PROGVERSION		"3.2"
+#define HB_UNSTABLE			0
+
+#define FILE_VERSION		0.3
+
+#if HB_UNSTABLE != 1
+	#define	PROGNAME		"HomeBank"
+	#define HB_DATA_PATH	".homebank"
+#else
+	#define	PROGNAME		"HomeBank (unstable)"
+	#define HB_DATA_PATH	".homebank_unstable"
+#endif
+
+#ifdef G_OS_WIN32
+#define GETTEXT_PACKAGE "homebank"
+#define LOCALE_DIR      "locale"
+#define PIXMAPS_DIR     "images"
+#define HELP_DIR        "help"
+#define PACKAGE_VERSION "4.0.1"
+#define PACKAGE         "homebank"
+#define VERSION         "4.0.1"
+//#define NOOFX
+
+#define ENABLE_NLS 1
+#endif
 
 
-#define FILE_VERSION	0.1
-
-
-
-/* for operatio dialog */
-#define GTK_RESPONSE_ADD 1
+/* for operation dialog */
+#define GTK_RESPONSE_ADD	 1
 
 /* container spacing */
 #define HB_MAINBOX_SPACING	12
-#define HB_BOX_SPACING	6
+#define HB_BOX_SPACING		6
 #define HB_HSPACE_SPACING	12
 #define HB_TABROW_SPACING	6
 #define HB_TABCOL_SPACING	6
@@ -78,14 +97,18 @@
 */
 struct HomeBank
 {
-	GtkWidget	*mainwindow;	//should be global to access attached window data
-	guint32		today;			//today's date
+	// data storage
+	//GList		*acc_list;		//accounts
+	GHashTable	*h_acc;			//accounts
+	//GList		*pay_list;		//payees
+	GHashTable	*h_pay;			//payees
+	//GList		*cat_list;		//categories
+	GHashTable	*h_cat;			//categories
+	GHashTable	*h_tag;			//tags
 
-	GList		*acc_list;		//accounts
-	GList		*pay_list;		//payees
-	GList		*cat_list;		//categories
 	GList		*arc_list;		//archives
 	GList		*ope_list;		//operations
+	GHashTable	*h_memo;		//memo/description
 
 	// wallet properties
 	gchar		*title;
@@ -98,29 +121,26 @@ struct HomeBank
 	gboolean	wallet_is_new;
 	gboolean	exists_old;
 
+	// other stuffs
+	guint32		today;			//today's date
 	gint		change;
-
 	gint		define_off;		//>0 when a stat, account window is opened
 	gboolean	minor;
-
-	//gchar		fmt_maj_number[16];
-	//gchar		fmt_min_number[16];
-
-	// pixbuf datas
+	GtkWidget	*mainwindow;	//should be global to access attached window data
 	GdkPixbuf	*lst_pixbuf[NUM_LST_PIXBUF];
 	gint		lst_pixbuf_maxwidth;
-
-
-
+	
 };
 
 gint homebank_question_dialog(GtkWindow *parent, gchar *title, gchar *message_format, ...);
 void homebank_message_dialog(GtkWindow *parent, GtkMessageType type, gchar *title, gchar *message_format, ...);
+gboolean homebank_chooser_open_qif(GtkWindow *parent, gchar **storage_ptr);
 gboolean homebank_csv_file_chooser(GtkWindow *parent, GtkFileChooserAction action, gchar **storage_ptr);
 gboolean homebank_file_chooser(GtkFileChooserAction action);
 gboolean homebank_folder_chooser(GtkWindow *parent, gchar *title, gchar **storage_ptr);
 gboolean homebank_alienfile_chooser(gchar *title);
 gchar *homebank_get_filename_with_extension(gchar *path, gchar *extension);
+gchar *homebank_get_filename_without_extension(gchar *path);
 void homebank_file_ensure_xhb(void);
 void homebank_backup_current_file(gchar *pathname);
 gboolean homebank_util_url_show (const gchar *url);
@@ -133,4 +153,8 @@ gboolean homebank_folder_chooser(GtkWindow *parent, gchar *title, gchar **storag
 
 gchar *homebank_get_filename_with_extension(gchar *path, gchar *extension);
 
+const gchar *homebank_app_get_pixmaps_dir (void);
+const gchar *homebank_app_get_locale_dir (void);
+const gchar *homebank_app_get_help_dir (void);
+
 #endif /* __HOMEBANK_H__ */
