@@ -39,17 +39,24 @@ extern struct Preferences *PREFS;
 
 static void homebank_pref_init_monetary(void)
 {
-	DB( g_print("(preferences) monetary\n") );
+	DB( g_print("\n** (preferences) monetary\n") );
 
 
 #ifdef G_OS_UNIX
 
 struct lconv *lc = localeconv();
 
-	DB( g_print("(preferences) monetary unix\n") );
+	DB( g_print("\n** (preferences) monetary unix\n") );
 
+	DB( g_print("mon_decimal_point is utf8: %d", g_utf8_validate(lc->mon_decimal_point, -1, NULL)) );
 	DB( g_print("mon_decimal_point '%s'\n", lc->mon_decimal_point) );
+	DB( g_print("mon_decimal_point %x %x %x %x\n", lc->mon_decimal_point[0], lc->mon_decimal_point[1], lc->mon_decimal_point[2], lc->mon_decimal_point[3]) );
+
+	DB( g_print("mon_thousands_sep is utf8: %d", g_utf8_validate(lc->mon_thousands_sep, -1, NULL)) );
 	DB( g_print("mon_thousands_sep '%s'\n", lc->mon_thousands_sep) );
+	DB( g_print("mon_thousands_sep %x %x %x %x\n", lc->mon_thousands_sep[0], lc->mon_thousands_sep[1], lc->mon_thousands_sep[2], lc->mon_thousands_sep[3]) );
+
+
 
 	DB( g_print("frac_digits '%d'\n", (gint)lc->frac_digits) );
 
@@ -59,39 +66,48 @@ struct lconv *lc = localeconv();
 
 	DB( g_print("n_cs_precedes '%d'\n", lc->n_cs_precedes) );
 
+	/* ok assign */
 
 	
 	if( lc->p_cs_precedes || lc->n_cs_precedes )
 	{
 		PREFS->base_cur.prefix_symbol = g_strdup(lc->currency_symbol);
-		PREFS->base_cur.suffix_symbol = g_strdup("");
+		PREFS->base_cur.suffix_symbol = NULL; //g_strdup("");
 		DB( g_print("locale mon cs is a prefix\n") );
 	}
 	else
 	{
-		PREFS->base_cur.prefix_symbol = g_strdup("");
+		PREFS->base_cur.prefix_symbol = NULL; //g_strdup("");
 		PREFS->base_cur.suffix_symbol = g_strdup(lc->currency_symbol);
 	}
 
 	PREFS->base_cur.decimal_char  = g_strdup(lc->mon_decimal_point);	
+	
 	PREFS->base_cur.grouping_char = g_strdup(lc->mon_thousands_sep);	
+	
+	//todo:fix
+	//PREFS->base_cur.grouping_char = g_locale_to_utf8(lc->mon_thousands_sep, -1, NULL, NULL, NULL);
+	//PREFS->base_cur.grouping_char = g_convert (lc->mon_thousands_sep, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
+	
+	DB( g_print(" -> grouping_char: '%s'\n", PREFS->base_cur.grouping_char) );
+	
 	PREFS->base_cur.frac_digits   = lc->frac_digits;
-
+	
 
 #else
 	#ifdef G_OS_WIN32
 	//todo: to be really set by a win32 specialist from the registry...
 	
-	PREFS->base_cur.prefix_symbol = g_strdup("");;
-	PREFS->base_cur.suffix_symbol = g_strdup("");;
+	PREFS->base_cur.prefix_symbol = NULL; //g_strdup("");
+	PREFS->base_cur.suffix_symbol = NULL; //g_strdup("");
 	PREFS->base_cur.decimal_char  = g_strdup(".");
-	PREFS->base_cur.grouping_char = g_strdup("");;
+	PREFS->base_cur.grouping_char = NULL; //g_strdup("");
 	PREFS->base_cur.frac_digits   = 2;
 	#else
-	PREFS->base_cur.prefix_symbol = g_strdup("");;
-	PREFS->base_cur.suffix_symbol = g_strdup("");;
+	PREFS->base_cur.prefix_symbol = NULL; //g_strdup("");
+	PREFS->base_cur.suffix_symbol = NULL; //g_strdup("");
 	PREFS->base_cur.decimal_char  = g_strdup(".");
-	PREFS->base_cur.grouping_char = g_strdup("");;
+	PREFS->base_cur.grouping_char = NULL; //g_strdup("");
 	PREFS->base_cur.frac_digits   = 2;
 	#endif
 #endif
@@ -123,13 +139,14 @@ static void homebank_pref_init_wingeometry(struct WinGeometry *wg, gint l, gint
 
 void homebank_pref_free(void)
 {
-	DB( g_print("(preferences) free\n") );
+	DB( g_print("\n** (preferences) free\n") );
 
 
 	g_free(PREFS->date_format);
 
 	g_free(PREFS->path_wallet);
 	g_free(PREFS->path_import);
+	g_free(PREFS->path_export);
 	//g_free(PREFS->path_navigator);
 
 	g_free(PREFS->base_cur.prefix_symbol);
@@ -149,7 +166,7 @@ void homebank_pref_free(void)
 void homebank_pref_setdefault(void)
 {
 
-	DB( g_print("(preferences) pref init\n") );
+	DB( g_print("\n** (preferences) pref init\n") );
 
 	homebank_pref_free();
 
@@ -157,8 +174,10 @@ void homebank_pref_setdefault(void)
 
 	PREFS->path_wallet = g_strdup_printf("%s", g_get_home_dir ());
 	PREFS->path_import = g_strdup_printf("%s", g_get_home_dir ());
+	PREFS->path_export = g_strdup_printf("%s", g_get_home_dir ());
 	//PREFS->path_navigator = g_strdup(DEFAULT_PATH_NAVIGATOR);
 
+	PREFS->loadlast = TRUE;
 
 	PREFS->color_exp  = DEFAULT_EXP_COLOR;
 	PREFS->color_inc  = DEFAULT_INC_COLOR;
@@ -204,14 +223,6 @@ void homebank_pref_setdefault(void)
 	//todo: add intelligence here
 	PREFS->euro_active  = FALSE;
 	
-	//todo add intelligence here
-	PREFS->minor_cur.prefix_symbol = g_strdup("");
-	PREFS->minor_cur.suffix_symbol = g_strdup("??");
-	PREFS->minor_cur.decimal_char  = g_strdup(".");	
-	PREFS->minor_cur.grouping_char = g_strdup(" ");
-	PREFS->minor_cur.frac_digits   = 2;
-
-	
 	PREFS->euro_country = 0;
 	PREFS->euro_value   = 1.0;
 	//PREFS->euro_nbdec   = 2;
@@ -232,8 +243,10 @@ void homebank_pref_setdefault(void)
 */
 void homebank_pref_createformat(void)
 {
+struct Currency *cur;
+gchar *ptr;
 
-	DB( g_print("(preferences) pref create format\n") );
+	DB( g_print("\n** (preferences) pref create format\n") );
 
 /*
 	if(PREFS->base_cur.grouping_char != NULL)
@@ -259,14 +272,45 @@ void homebank_pref_createformat(void)
 
 	DB( g_print("+ minor is: '%s'\n", GLOBALS->fmt_min_number) );
 */
-	/* new fmt */
-	g_snprintf(PREFS->base_cur.format , 8-1, "%%.%df", PREFS->base_cur.frac_digits);
-	g_snprintf(PREFS->minor_cur.format, 8-1, "%%.%df", PREFS->minor_cur.frac_digits);
+	/* base format */
+	cur = &PREFS->base_cur;
+
+	g_snprintf(cur->format , 8-1, "%%.%df", cur->frac_digits);
+
+	ptr = cur->monfmt;
+	if(cur->prefix_symbol != NULL)
+	{
+		ptr = g_stpcpy(ptr, cur->prefix_symbol);
+		ptr = g_stpcpy(ptr, " ");
+	}
+	ptr = g_stpcpy(ptr, "%s");
+	if(cur->suffix_symbol != NULL)
+	{
+		ptr = g_stpcpy(ptr, " ");
+		ptr = g_stpcpy(ptr, cur->suffix_symbol);
+	}
+
+	cur = &PREFS->minor_cur;
+
+	g_snprintf(cur->format , 8-1, "%%.%df", cur->frac_digits);
+
+	ptr = cur->monfmt;
+	if(cur->prefix_symbol != NULL)
+	{
+		ptr = g_stpcpy(ptr, cur->prefix_symbol);
+		ptr = g_stpcpy(ptr, " ");
+	}
+	ptr = g_stpcpy(ptr, "%s");
+	if(cur->suffix_symbol != NULL)
+	{
+		ptr = g_stpcpy(ptr, " ");
+		ptr = g_stpcpy(ptr, cur->suffix_symbol);
+	}
 
 }
 
 /*
-** load preference from homedir/.homebank
+** load preference from homedir/.homebank (HB_DATA_PATH)
 */
 static void homebank_pref_get_wingeometry(
 	GKeyFile *key_file,
@@ -361,7 +405,7 @@ gchar *string;
 		*storage = NULL;
 		
 		string = g_key_file_get_string(key_file, group_name, key, NULL);
-		if( string != "" )
+		if( string != NULL )
 		{
 			*storage = g_strdup(string);
 			
@@ -389,12 +433,17 @@ gboolean retval = FALSE;
 gchar *group, *filename;
 GError *error = NULL;
 
-	DB( g_print("(preferences) pref load\n") );
+	DB( g_print("\n** (preferences) pref load\n") );
 
 	keyfile = g_key_file_new();
 	if(keyfile)
 	{
-		filename = g_strdup_printf("%s/.homebank/preferences", g_get_home_dir ());
+		//filename = g_strdup_printf("%s/" HB_DATA_PATH "/preferences", g_get_home_dir ());
+		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "preferences", NULL );
+
+		DB( g_print(" filename: %s\n", filename) );
+
+
 		if(g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, NULL))
 		{
 
@@ -416,8 +465,11 @@ GError *error = NULL;
 				
 				homebank_pref_get_string(keyfile, group, "WalletPath", &PREFS->path_wallet);
 				homebank_pref_get_string(keyfile, group, "ImportPath", &PREFS->path_import);
+				homebank_pref_get_string(keyfile, group, "ExportPath", &PREFS->path_export);
 				//homebank_pref_get_string(keyfile, group, "NavigatorPath", &PREFS->path_navigator);
 
+				homebank_pref_get_boolean(keyfile, group, "LoadLast", &PREFS->loadlast);
+
 				
 				if( g_key_file_has_key(keyfile, group, "ColumnsOpe", NULL) )
 				{
@@ -532,24 +584,44 @@ GError *error = NULL;
 	return retval;
 }
 
+static void homebank_pref_set_string(
+	GKeyFile *key_file,
+    const gchar *group_name,
+    const gchar *key,
+	gchar *string)
+{
+
+	DB( g_print(" -> homebank_pref_set_string :: group='%s' key='%s' value='%s'\n", group_name, key, string) );
+
+	if( string != NULL && *string != '\0')
+		g_key_file_set_string  (key_file, group_name, key, string);
+	//else
+	//	g_key_file_set_string  (key_file, group_name, key, "");
+		
+}
+
 
 /*
-** save preference to homedir/.homebank
+** save preference to homedir/.homebank (HB_DATA_PATH)
 */
 gboolean homebank_pref_save(void)
 {
 GKeyFile *keyfile;
 gboolean retval = FALSE;
 gchar *group, *filename;
-guint length;
+gsize length;
 
-	DB( g_print("(preferences) pref save\n") );
+	DB( g_print("\n** (preferences) pref save\n") );
 
 	keyfile = g_key_file_new();
 	if(keyfile )
 	{
+
+		DB( g_print(" -> ** general\n") );
+
+
 		group = "General";
-		g_key_file_set_string  (keyfile, group, "Version", PREF_VERSION);
+		homebank_pref_set_string  (keyfile, group, "Version", PREF_VERSION);
 
 		g_key_file_set_integer (keyfile, group, "BarStyle", PREFS->toolbar_style);
 		//g_key_file_set_integer (keyfile, group, "BarImageSize", PREFS->image_size);
@@ -562,13 +634,17 @@ guint length;
 		g_key_file_set_boolean (keyfile, group, "RunWizard", PREFS->runwizard);
 		#endif
 
-		g_key_file_set_string  (keyfile, group, "WalletPath"   , PREFS->path_wallet);
-		g_key_file_set_string  (keyfile, group, "ImportPath"   , PREFS->path_import);
+		homebank_pref_set_string  (keyfile, group, "WalletPath"   , PREFS->path_wallet);
+		homebank_pref_set_string  (keyfile, group, "ImportPath"   , PREFS->path_import);
+		homebank_pref_set_string  (keyfile, group, "ExportPath"   , PREFS->path_export);
 		//g_key_file_set_string  (keyfile, group, "NavigatorPath", PREFS->path_navigator);
 
+		g_key_file_set_boolean (keyfile, group, "LoadLast", PREFS->loadlast);
 		g_key_file_set_boolean_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_COL_OPE);
 
 		// added v3.4
+		DB( g_print(" -> ** windows\n") );
+
 		group = "Windows";
 		g_key_file_set_integer_list(keyfile, group, "Wal", (gint *)&PREFS->wal_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Acc", (gint *)&PREFS->acc_wg, 4);
@@ -577,34 +653,45 @@ guint length;
 		g_key_file_set_integer_list(keyfile, group, "Bud", (gint *)&PREFS->bud_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Car", (gint *)&PREFS->car_wg, 4);
 
-		group = "Format";
-		g_key_file_set_string  (keyfile, group, "DateFmt"   , PREFS->date_format);
+		DB( g_print(" -> ** format\n") );
 
-		g_key_file_set_string  (keyfile, group, "PreSymbol" , PREFS->base_cur.prefix_symbol);
-		g_key_file_set_string  (keyfile, group, "SufSymbol" , PREFS->base_cur.suffix_symbol);
-		g_key_file_set_string  (keyfile, group, "DecChar"   , PREFS->base_cur.decimal_char);
-		g_key_file_set_string  (keyfile, group, "GroupChar" , PREFS->base_cur.grouping_char);
+		group = "Format";
+		homebank_pref_set_string  (keyfile, group, "DateFmt"   , PREFS->date_format);
+
+		homebank_pref_set_string  (keyfile, group, "PreSymbol" , PREFS->base_cur.prefix_symbol);
+		homebank_pref_set_string  (keyfile, group, "SufSymbol" , PREFS->base_cur.suffix_symbol);
+		homebank_pref_set_string  (keyfile, group, "DecChar"   , PREFS->base_cur.decimal_char);
+		homebank_pref_set_string  (keyfile, group, "GroupChar" , PREFS->base_cur.grouping_char);
 		g_key_file_set_integer (keyfile, group, "FracDigits", PREFS->base_cur.frac_digits);
 
 		g_key_file_set_boolean (keyfile, group, "UKUnits" , PREFS->imperial_unit);
 
+		DB( g_print(" -> ** filter\n") );
+
 		group = "Filter";
 		g_key_file_set_integer (keyfile, group, "DefRange", PREFS->filter_range);
 
+		DB( g_print(" -> ** euro\n") );
+
 	//euro options
 		group = "Euro";
 		g_key_file_set_boolean (keyfile, group, "Active" , PREFS->euro_active);
-		g_key_file_set_integer (keyfile, group, "Country", PREFS->euro_country);
-		gchar ratestr[64];
-		g_ascii_dtostr(ratestr, 63, PREFS->euro_value);
-		g_key_file_set_string  (keyfile, group, "ChangeRate", ratestr);
-		g_key_file_set_string  (keyfile, group, "PreSymbol" , PREFS->minor_cur.prefix_symbol);
-		g_key_file_set_string  (keyfile, group, "SufSymbol" , PREFS->minor_cur.suffix_symbol);
-		g_key_file_set_string  (keyfile, group, "DecChar"   , PREFS->minor_cur.decimal_char);
-		g_key_file_set_string  (keyfile, group, "GroupChar" , PREFS->minor_cur.grouping_char);
-		g_key_file_set_integer (keyfile, group, "FracDigits", PREFS->minor_cur.frac_digits);
+		if( PREFS->euro_active )
+		{	
+			g_key_file_set_integer (keyfile, group, "Country", PREFS->euro_country);
+			gchar ratestr[64];
+			g_ascii_dtostr(ratestr, 63, PREFS->euro_value);
+			homebank_pref_set_string  (keyfile, group, "ChangeRate", ratestr);
+			homebank_pref_set_string  (keyfile, group, "PreSymbol" , PREFS->minor_cur.prefix_symbol);
+			homebank_pref_set_string  (keyfile, group, "SufSymbol" , PREFS->minor_cur.suffix_symbol);
+			homebank_pref_set_string  (keyfile, group, "DecChar"   , PREFS->minor_cur.decimal_char);
+			homebank_pref_set_string  (keyfile, group, "GroupChar" , PREFS->minor_cur.grouping_char);
+			g_key_file_set_integer (keyfile, group, "FracDigits", PREFS->minor_cur.frac_digits);
+		}
 
 	//report options
+		DB( g_print(" -> ** report\n") );
+
 		group = "Report";
 		g_key_file_set_boolean (keyfile, group, "StatByAmount", PREFS->stat_byamount);
 		g_key_file_set_boolean (keyfile, group, "StatDetail"  , PREFS->stat_showdetail);
@@ -618,15 +705,28 @@ guint length;
 		//g_key_file_set_boolean (keyfile, group, "", PREFS->);
 		//g_key_file_set_integer (keyfile, group, "", PREFS->);
 
+		DB( g_print(" -> ** g_key_file_to_data\n") );
+
 		gchar *contents = g_key_file_to_data (keyfile, &length, NULL);
 
 		//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
-		filename = g_strdup_printf("%s/.homebank/preferences", g_get_home_dir ());
+		//filename = g_strdup_printf("%s/" HB_DATA_PATH "/preferences", g_get_home_dir ());
+		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "preferences", NULL );
+
+		DB( g_print(" -> filename: %s\n", filename) );
+
 		g_file_set_contents(filename, contents, length, NULL);
+
+		DB( g_print(" -> freeing filename\n") );
 		g_free(filename);
 
+		DB( g_print(" -> freeing buffer\n") );
+
 		g_free(contents);
+
+		DB( g_print(" -> freeing keyfile\n") );
+
 		g_key_file_free (keyfile);
 	}
 
