@@ -20,6 +20,7 @@
 
 #include "homebank.h"
 
+#include "gtkchart.h"
 #include "dsp_wallet.h"
 #include "rep_budget.h"
 #include "list_operation.h"
@@ -388,7 +389,7 @@ struct repbudget_data *data;
 
 			//DB( g_print(" - active is %d\n", pos) );
 
-			repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), (gpointer)key);
+			repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
 		}
 
 
@@ -403,7 +404,7 @@ struct repbudget_data *data;
 static void repbudget_detail(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
-guint active = (gint)user_data;
+guint active = GPOINTER_TO_INT(user_data);
 GList *list;
 GtkTreeModel *model;
 GtkTreeIter  iter;
@@ -494,7 +495,8 @@ gint nbmonth = 1;
 	nbmonth = countmonth(mindate, maxdate);
 	DB( g_print(" date: min=%d max=%d nbmonth=%d\n", mindate, maxdate, nbmonth) );
 
-	n_result = g_list_length(GLOBALS->cat_list);
+	n_result = da_cat_get_max_key();
+	DB( g_print(" nbcat=%d\n", n_result) );
 
 	/* allocate some memory */
 	tmp_spent  = g_malloc0((n_result+1) * sizeof(gdouble));
@@ -515,8 +517,8 @@ gint nbmonth = 1;
 
 			DB( g_print("%d, get ope: %s :: acc=%d\n", i, ope->wording, ope->account) );
 
-			acc = g_list_nth_data(GLOBALS->acc_list, ope->account);
-			if(acc!=NULL)
+			acc = da_acc_get(ope->account);
+			if(acc != NULL)
 			{
 				if((acc->flags & AF_CLOSED)) goto next;
 				if(!(acc->flags & AF_BUDGET)) goto next;
@@ -526,10 +528,11 @@ gint nbmonth = 1;
 				gint pos;
 
 					pos = ope->category;
-					tmp_spent[pos] += ope->amount;
+					if( pos >= 0)
+						tmp_spent[pos] += ope->amount;
 				}
-			}
-	
+			}	
+
 		next:
 			list = g_list_next(list);
 			i++;
@@ -547,11 +550,14 @@ gint nbmonth = 1;
 		for(i=0, id=0; i<n_result; i++)
 		{
 		gchar *name, *fullcatname;
+		Category *entry;
 		//gchar buffer[128];
 
 			fullcatname = NULL;
 
-			Category *entry = g_list_nth_data(GLOBALS->cat_list, i);
+			entry = da_cat_get(i);
+			if( entry == NULL)
+				continue;
 
 			//debug
 			#if MYDEBUG == 1
@@ -568,7 +574,7 @@ gint nbmonth = 1;
 
 			if(entry->flags & GF_SUB)
 			{
-			Category *parent = g_list_nth_data(GLOBALS->cat_list, entry->parent);
+			Category *parent = da_cat_get( entry->parent);
 
 				fullcatname = g_strdup_printf("%s:%s", parent->name, entry->name);
 				name = fullcatname;
@@ -587,13 +593,13 @@ gint nbmonth = 1;
 				DB( g_print(" cat %s -> monthly %.2f\n", name, entry->budget[0]) );
 				tmp_budget[i] = entry->budget[0]*nbmonth;
 			}
-			//otherwise	sum each month from mindate month			
+			//otherwise	sum each month from mindate month		
 			else
 			{
 			gint month = getmonth(mindate);
 			gint j;
 
-		DB( g_print(" cat '%s' -> custom month=%ld nbmonth=%ld\n", name, month, nbmonth) );
+				DB( g_print(" cat '%s' -> custom month=%ld nbmonth=%ld\n", name, month, nbmonth) );
 
 				for(j=0;j<nbmonth;j++)
 				{
@@ -604,7 +610,7 @@ gint nbmonth = 1;
 					if(month > 12) month = 1;
 				}
 
-
+				
 			}
 
 
@@ -752,7 +758,7 @@ struct repbudget_data *data;
 	//active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_legend));
 	data->legend ^= 1;
 
-	gtk_chart_set_legend(GTK_CHART(data->RE_bar), data->legend);
+	gtk_chart_show_legend(GTK_CHART(data->RE_bar), data->legend);
 
 }
 
@@ -771,7 +777,7 @@ gboolean minor;
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_report));
 
 	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
-	gtk_chart_set_minor(GTK_CHART(data->RE_bar), minor);
+	gtk_chart_show_minor(GTK_CHART(data->RE_bar), minor);
 
 }
 
@@ -791,7 +797,7 @@ guint key;
 
 		DB( g_print(" - active is %d\n", key) );
 
-		repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), (gpointer)key);
+		repbudget_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
 	}
 
 	repbudget_sensitive(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), NULL);
@@ -817,7 +823,7 @@ struct WinGeometry *wg;
 
 	//enable define windows
 	GLOBALS->define_off--;
-	wallet_update(GLOBALS->mainwindow, (gpointer)2);
+	wallet_update(GLOBALS->mainwindow, GINT_TO_POINTER(2));
 
 	DB( g_print("(repbudget) end dispose\n") );
 
@@ -844,7 +850,7 @@ GError *error = NULL;
 
 	//disable define windows
 	GLOBALS->define_off++;
-	wallet_update(GLOBALS->mainwindow, (gpointer)2);
+	wallet_update(GLOBALS->mainwindow, GINT_TO_POINTER(2));
 
     /* create window, etc */
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -1163,7 +1169,7 @@ gchar *markuptxt;
 guint32 color;
 
 	//get datas
-	gtk_tree_model_get(model, iter, user_data, &value, -1);
+	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &value, -1);
 
 	if( value )
 	{
@@ -1200,8 +1206,8 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, budget_amount_cell_data_function, (gpointer)id, NULL);
-	gtk_tree_view_column_set_alignment (column, 1.0);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, budget_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
@@ -1242,6 +1248,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_add_attribute(column, renderer, "text", LST_BUDGET_NAME);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_STAT_NAME);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Expense */
