@@ -20,10 +20,10 @@
 
 #include "homebank.h"
 #include "gtkchart.h"
-#include "dsp_wallet.h"
 #include "rep_stats.h"
 #include "list_operation.h"
 #include "def_filter.h"
+#include "dsp_wallet.h"
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -185,9 +185,17 @@ static GtkWidget *create_list_statistic(void);
 
 static gint stat_list_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata);
 
+enum
+{
+	STAT_CATEGORY,
+	STAT_SUBCATEGORY,
+	STAT_PAYEE,
+	STAT_TAG,
+	STAT_MONTH,
+	STAT_YEAR,
+};
 
-
-gchar *CYA_STATSELECT[] = { N_("Category"), N_("Payee"), N_("Month"), N_("Year"), NULL };
+gchar *CYA_STATSELECT[] = { N_("Category"), N_("Subcategory"), N_("Payee"), N_("Tag"), N_("Month"), N_("Year"), NULL };
 
 
 
@@ -506,7 +514,7 @@ GDate *date;
 static void statistic_detail(GtkWidget *widget, gpointer user_data)
 {
 struct statistic_data *data;
-guint active = (gint)user_data;
+guint active = GPOINTER_TO_INT(user_data);
 guint tmpfor;
 GList *list;
 GtkTreeModel *model;
@@ -516,9 +524,9 @@ GtkTreeIter  iter;
 
 	DB( g_print("(statistic) detail\n") );
 
-		/* clear and detach our model */
-		model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
-		gtk_list_store_clear (GTK_LIST_STORE(model));
+	/* clear and detach our model */
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
+	gtk_list_store_clear (GTK_LIST_STORE(model));
 
 	if(data->detail && active != -1)
 	{
@@ -540,39 +548,78 @@ GtkTreeIter  iter;
 			{
 			gint pos = 0;
 
-				switch(tmpfor)
-				{
-					case 0:	/* category */
-						pos = ope->category;
-						break;
-					case 1: /* payee */
-						pos = ope->payee;
-						break;
-					case 2: /* period */
-						pos = DateInPer(data->filter->mindate, ope->date);
-						break;
-					case 3: /* year */
-						pos = DateInYear(data->filter->mindate, ope->date);
-						break;
-				}
-
-				//insert
-				if( pos == active )
+				if( tmpfor != STAT_TAG )
 				{
 
-			    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-		     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-						LST_DSPOPE_DATAS, ope,
-						-1);
+					switch(tmpfor)
+					{
+						case STAT_CATEGORY:
+							pos = ope->category;
+							break;
+						case STAT_SUBCATEGORY:
+							pos = ope->category;
+							break;
+						case STAT_PAYEE:
+							pos = ope->payee;
+							break;
 
-				/*
-				if(ApplyFilter(&data->flt, ope))
+						case STAT_MONTH:
+							pos = DateInPer(data->filter->mindate, ope->date);
+							break;
+						case STAT_YEAR:
+							pos = DateInYear(data->filter->mindate, ope->date);
+							break;
+					}
+
+					//insert
+					if( pos == active )
+					{
+
+				    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+			     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+							LST_DSPOPE_DATAS, ope,
+							-1);
+
+					/*
+					if(ApplyFilter(&data->flt, ope))
+					{
+						DoMethod(data->LV_detail, MUIM_NList_InsertSingle, ope, MUIV_NList_Insert_Bottom);
+					}
+					*/
+					}
+
+
+				}
+				else
+				/* the TAG process is particular */
 				{
-					DoMethod(data->LV_detail, MUIM_NList_InsertSingle, ope, MUIV_NList_Insert_Bottom);
-				}
-				*/
+					if(ope->tags != NULL)
+					{
+					guint32 *tptr = ope->tags;
+					
+						while(*tptr)
+						{
+							pos = *tptr - 1;
+	
+							DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
+
+							if( pos == active )
+							{
+						    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+					     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+									LST_DSPOPE_DATAS, ope,
+									-1);
+
+							}
+	
+							tptr++;
+						} 	
+
+					}
 				}
 
+
+
 			}
 			list = g_list_next(list);
 		}
@@ -594,7 +641,8 @@ static void statistic_update(GtkWidget *widget, gpointer user_data)
 struct statistic_data *data;
 gboolean byamount;
 GtkTreeModel		 *model;
-gint page, tmpkind, column;
+gint page, tmpfor, tmpkind, column;
+gboolean xval;
 
 	DB( g_print("(statistic) update\n") );
 
@@ -603,6 +651,7 @@ gint page, tmpkind, column;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report));
 	byamount = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_byamount));
+	tmpfor  = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
 	tmpkind = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_view));
 
 	// ensure not exp & inc for piechart
@@ -620,7 +669,7 @@ gint page, tmpkind, column;
 	DB( g_print(" tmpkind %d\n\n", tmpkind) );
 
 
-	column = byamount ? LST_STAT_EXPENSE+tmpkind-1 : LST_STAT_POS;
+	column = byamount ? LST_STAT_EXPENSE+(tmpkind-1)*2 : LST_STAT_POS;
 	DB( g_print(" sort on column %d\n\n", column) );
 
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), column, GTK_SORT_DESCENDING);
@@ -635,6 +684,30 @@ gint page, tmpkind, column;
 		gtk_chart_set_datas(GTK_CHART(data->RE_bar), model, column);
 	gtk_chart_set_title(GTK_CHART(data->RE_bar), _(CYA_KIND2[tmpkind]));
 	
+	
+	/* show xval for month/year and no by amount display */
+	xval = FALSE;
+	
+	
+	if( !byamount && (tmpfor == STAT_MONTH || tmpfor == STAT_YEAR) )
+	{
+		xval = TRUE;
+		switch( tmpfor)
+		{
+			case STAT_MONTH:
+				gtk_chart_set_decy_xval(GTK_CHART(data->RE_bar), 4);
+				break;
+			case STAT_YEAR:
+				gtk_chart_set_decy_xval(GTK_CHART(data->RE_bar), 2);
+				break;
+	
+		}
+		
+		
+	}
+	
+	gtk_chart_show_xval(GTK_CHART(data->RE_bar), xval);
+	
 	/* update pie chart */
 	DB( g_print(" set pie to %d %s\n\n", column, _(CYA_KIND2[tmpkind])) );
 	if( tmpkind != 0 )
@@ -698,20 +771,26 @@ gdouble exprate, incrate, balrate;
 	/* count number or results */
 	switch(tmpfor)
 	{
-		case 0:	/* group */
-			n_result = g_list_length(GLOBALS->cat_list);
+		case STAT_CATEGORY:
+			n_result = da_cat_get_max_key();
 			break;
-		case 1:	/* payee */
-			n_result = g_list_length(GLOBALS->pay_list);
+		case STAT_SUBCATEGORY:
+			n_result = da_cat_get_max_key();
 			break;
-		case 2: /* month */
+		case STAT_PAYEE:
+			n_result = da_pay_get_max_key();
+			break;
+		case STAT_TAG:
+			n_result = da_tag_length();
+			break;
+		case STAT_MONTH:
 			date1 = g_date_new_julian(from);
 			date2 = g_date_new_julian(to);
 			n_result = ((g_date_get_year(date2) - g_date_get_year(date1)) * 12) + g_date_get_month(date2) - g_date_get_month(date1) + 1;
 			g_date_free(date2);
 			g_date_free(date1);
 			break;
-		case 3: /* year  */
+		case STAT_YEAR:
 			date1 = g_date_new_julian(from);
 			date2 = g_date_new_julian(to);
 			n_result = g_date_get_year(date2) - g_date_get_year(date1) + 1;
@@ -745,37 +824,77 @@ gdouble exprate, incrate, balrate;
 
 			if(filter_test(data->filter, ope) == 1)
 			{
-			gint pos = 0;
+			guint32 pos = 0;
 
-				switch(tmpfor)
+				if( tmpfor != STAT_TAG )
 				{
-					case 0:	/* category */
-						pos = ope->category;
-						break;
-					case 1: /* payee */
-						pos = ope->payee;
-						break;
-					case 2: /* period */
-						pos = DateInPer(from, ope->date);
-						break;
-					case 3: /* year */
-						pos = DateInYear(from, ope->date);
-						break;
-				}
+					switch(tmpfor)
+					{
+						case STAT_CATEGORY:
+							{
+							Category *catentry = da_cat_get(ope->category);
+								if(catentry)
+									pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
+							}
+							break;
+						case STAT_SUBCATEGORY:
+							pos = ope->category;
+							break;
+						case STAT_PAYEE:
+							pos = ope->payee;
+							break;
+						case STAT_MONTH:
+							pos = DateInPer(from, ope->date);
+							break;
+						case STAT_YEAR:
+							pos = DateInYear(from, ope->date);
+							break;
+					}
 
-				// add the amount
-				if(ope->amount > 0)
-				{
-					tmp_income[pos] += ope->amount;
-					data->total_income  += ope->amount;
+					if(pos >= 0)
+					{// add the amount
+						if(ope->amount > 0)
+						{
+							tmp_income[pos] += ope->amount;
+							data->total_income  += ope->amount;
+						}
+						else
+						{
+							tmp_expense[pos] += ope->amount;
+							//data->total_expense += ABS(ope->amount);
+							data->total_expense += ope->amount;
+						}
+					}
 				}
 				else
+				/* the TAG process is particular */
 				{
-					tmp_expense[pos] += ope->amount;
-					//data->total_expense += ABS(ope->amount);
-					data->total_expense += ope->amount;
-				}
+					if(ope->tags != NULL)
+					{
+					guint32 *tptr = ope->tags;
+					
+						while(*tptr)
+						{
+							pos = *tptr - 1;
+	
+							DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
+	
+							if(ope->amount > 0)
+							{
+								tmp_income[pos] += ope->amount;
+							}
+							else
+							{
+								tmp_expense[pos] += ope->amount;
+							}							
+							tptr++;
+						} 	
 
+						data->total_income  += ope->amount;
+						data->total_expense += ope->amount;
+
+					}
+				}
 
 
 
@@ -805,7 +924,7 @@ gdouble exprate, incrate, balrate;
 			fullcatname = NULL;
 
 			/* filter empty results */
-			if(tmpfor < 2 )
+			if(tmpfor == STAT_CATEGORY || tmpfor == STAT_SUBCATEGORY || tmpfor == STAT_PAYEE || tmpfor == STAT_TAG)
 			{
 				if( tmpkind == 1 && !tmp_expense[i] ) continue;
 				if( tmpkind == 2 && !tmp_income[i] ) continue;
@@ -815,28 +934,49 @@ gdouble exprate, incrate, balrate;
 			/* get the result name */
 			switch(tmpfor)
 			{
-				case 0:	/* category */
+				case STAT_CATEGORY:
 					{
-					Category *entry = g_list_nth_data(GLOBALS->cat_list, i);
+					Category *entry = da_cat_get(i);
 
-						if(entry->flags & GF_SUB)
+						if(entry != NULL)
+							name = entry->key == 0 ? _("(none)") : entry->name;
+					}
+					break;
+
+				case STAT_SUBCATEGORY:
+					{
+					Category *entry = da_cat_get(i);
+						if(entry != NULL)
 						{
-						Category *parent = g_list_nth_data(GLOBALS->cat_list, entry->parent);
+							if(entry->flags & GF_SUB)
+							{
+							Category *parent = da_cat_get(entry->parent);
 
-							fullcatname = g_strdup_printf("%s:%s", parent->name, entry->name);
-							name = fullcatname;
+								fullcatname = g_strdup_printf("%s : %s", parent->name, entry->name);
+								name = fullcatname;
+							}
+							else
+								name = entry->key == 0 ? _("(none)") : entry->name;
 						}
-						else
-							name = entry->name;
 					}
 					break;
-				case 1: /* payee */
+
+				case STAT_PAYEE:
 					{
-					Payee *entry = g_list_nth_data(GLOBALS->pay_list, i);
-					name = entry->name;
+					Payee *entry = da_pay_get(i);
+						if(entry != NULL)
+							name = entry->key == 0 ? _("(none)") : entry->name;
 					}
 					break;
-				case 2: /* period */
+
+				case STAT_TAG:
+					{
+					Tag *entry = da_tag_get(i+1);
+						name = entry->name;
+					}
+					break;
+
+				case STAT_MONTH:
 					date = g_date_new_julian(from);
 					g_date_add_months(date, i);
 					//g_snprintf(buffer, 63, "%d-%02d", g_date_get_year(date), g_date_get_month(date));
@@ -844,7 +984,8 @@ gdouble exprate, incrate, balrate;
 					g_date_free(date);
 					name = buffer;
 					break;
-				case 3: /* year */
+
+				case STAT_YEAR:
 					date = g_date_new_julian(from);
 					g_date_add_years(date, i);
 					g_snprintf(buffer, 63, "%d", g_date_get_year(date));
@@ -853,12 +994,7 @@ gdouble exprate, incrate, balrate;
 					break;
 			}
 
-			if(name == NULL) name  = "(None)";
-
-			//g_print(" inserting %i, %s\n", i, name);
-
-
-			DB( g_print(" inserting %2d, %48s, %9.2f %9.2f %9.2f\n", i, name, tmp_expense[i], tmp_income[i], tmp_expense[i] + tmp_income[i]) );
+			DB( g_print(" inserting %2d, '%s', %9.2f %9.2f %9.2f\n", i, name, tmp_expense[i], tmp_income[i], tmp_expense[i] + tmp_income[i]) );
 
 			//compute rate
 			exprate = 0.0;
@@ -956,7 +1092,7 @@ gint page, view;
 	view = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_view));
 
 	sensitive = page == 0 ? FALSE : TRUE;
-//	gtk_widget_set_sensitive(data->CY_view, sensitive);
+	//gtk_widget_set_sensitive(data->CY_view, sensitive);
 //	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_LEGEND], sensitive);
 	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Legend"), sensitive);
 
@@ -984,7 +1120,7 @@ struct statistic_data *data;
 
 			DB( g_print(" - active is %d\n", key) );
 
-			statistic_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), (gpointer)key);
+			statistic_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
 		}
 
 
@@ -1028,8 +1164,8 @@ struct statistic_data *data;
 
 	//active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_legend));
 
-	gtk_chart_set_legend(GTK_CHART(data->RE_bar), data->legend);
-	gtk_chart_set_legend(GTK_CHART(data->RE_pie), data->legend);
+	gtk_chart_show_legend(GTK_CHART(data->RE_bar), data->legend);
+	gtk_chart_show_legend(GTK_CHART(data->RE_pie), data->legend);
 
 }
 
@@ -1074,8 +1210,8 @@ gboolean minor;
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_report));
 
 	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
-	gtk_chart_set_minor(GTK_CHART(data->RE_bar), minor);
-	gtk_chart_set_minor(GTK_CHART(data->RE_pie), minor);
+	gtk_chart_show_minor(GTK_CHART(data->RE_bar), minor);
+	gtk_chart_show_minor(GTK_CHART(data->RE_pie), minor);
 
 }
 
@@ -1203,7 +1339,7 @@ guint key = -1;
 
 	DB( g_print(" - active is %d\n", key) );
 
-	statistic_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), (gpointer)key);
+	statistic_detail(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(key));
 	statistic_sensitive(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), NULL);
 }
 
@@ -1233,7 +1369,7 @@ struct WinGeometry *wg;
 
 	//enable define windows
 	GLOBALS->define_off--;
-	wallet_update(GLOBALS->mainwindow, (gpointer)2);
+	wallet_update(GLOBALS->mainwindow, GINT_TO_POINTER(2));
 
 	return FALSE;
 }
@@ -1255,7 +1391,7 @@ GError *error = NULL;
 
 	//disable define windows
 	GLOBALS->define_off++;
-	wallet_update(GLOBALS->mainwindow, (gpointer)2);
+	wallet_update(GLOBALS->mainwindow, GINT_TO_POINTER(2));
 
     /* create window, etc */
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -1575,7 +1711,7 @@ static void statistic_rate_cell_data_function (GtkTreeViewColumn *col,
      //todo
 	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
-	gtk_tree_model_get(model, iter, user_data, &tmp, -1);
+	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &tmp, -1);
 
 	if(tmp != 0.0)
 	{
@@ -1602,7 +1738,7 @@ gchar *markuptxt;
 guint32 color;
 
 	//get datas
-	gtk_tree_model_get(model, iter, user_data, &value, -1);
+	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &value, -1);
 
 	if( value )
 	{
@@ -1640,8 +1776,8 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, statistic_amount_cell_data_function, (gpointer)id, NULL);
-	gtk_tree_view_column_set_alignment (column, 1.0);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, statistic_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
@@ -1657,8 +1793,8 @@ GtkCellRenderer    *renderer;
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", id);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, statistic_rate_cell_data_function, (gpointer)id, NULL);
-	gtk_tree_view_column_set_alignment (column, 1.0);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, statistic_rate_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 
 	//gtk_tree_view_column_set_visible(column, FALSE);
@@ -1705,6 +1841,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_add_attribute(column, renderer, "text", LST_STAT_NAME);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_STAT_NAME);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Expense */
