@@ -17,8 +17,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __HOMEBANK_XML_H__
-#define __HOMEBANK_XML_H__
+#ifndef __HB_XML_H__
+#define __HB_XML_H__
 
 gint homebank_load_xml(gchar *filename);
 void homebank_save_xml(gchar *filename);
@@ -32,4 +32,4 @@ enum
 };
 
 
-#endif /* __HOMEBANK_XML_H__ */
+#endif
